@@ -5,7 +5,7 @@ use common::sense;
 use v5.12;
 
 use Moose::Role;
-
+use List::Util qw/ uniq /;
 use XML::Simple;
 
 has 'sitemap_uri' => (
@@ -28,7 +28,7 @@ sub BUILD {
 
     my $data = XMLin($http_resource->content);
 
-    push @{ $self->locations }, URI->new($_->{loc}) foreach @{ $data->{url} };
+    push @{ $self->locations }, URI->new($_->{loc}) foreach uniq(@{ $data->{url} });
 }
 
 sub next {
@@ -41,4 +41,4 @@ sub next {
     return $self->ua->get($next);
 }
 
-1;
\ No newline at end of file
+1;
